package Mojar::Mysql;
use Mojo::Base -strict;

our $VERSION = 2.072;

1;
__END__

=head1 NAME

Mojar::Mysql - Suite of MySQL integration tools.

=head1 DESCRIPTION

This release includes the database connector L<Mojar::Mysql::Connector>, and
the utility pack L<Mojar::Mysql::Util>.
